@@ -3,7 +3,6 @@ package runner
 import (
 	"errors"
 	"fmt"
-	"io/ioutil"
 	"log"
 	"net"
 	"os"
@@ -11,6 +10,7 @@ import (
 	"os/signal"
 	"runtime"
 	"strings"
+	"sync"
 	"sync/atomic"
 	"syscall"
 	"testing"
@@ -296,9 +296,12 @@ func TestRebuild(t *testing.T) {
 	if err != nil {
 		t.Fatalf("Should not be fail: %s.", err)
 	}
+	wg := sync.WaitGroup{}
+	wg.Add(1)
 	go func() {
 		engine.Run()
 		t.Logf("engine stopped")
+		wg.Done()
 	}()
 	err = waitingPortReady(t, port, time.Second*10)
 	if err != nil {
@@ -334,8 +337,9 @@ func TestRebuild(t *testing.T) {
 	t.Logf("port is ready")
 	// stop engine
 	engine.Stop()
-	time.Sleep(time.Second * 1)
 	t.Logf("engine stopped")
+	wg.Wait()
+	time.Sleep(time.Second * 1)
 	assert.True(t, checkPortConnectionRefused(port))
 }
 
@@ -383,7 +387,9 @@ func TestCtrlCWhenHaveKillDelay(t *testing.T) {
 	engine.config.Build.KillDelay = c.Build.KillDelay
 	engine.config.Build.Delay = 2000
 	engine.config.Build.SendInterrupt = true
-	engine.config.preprocess()
+	if err := engine.config.preprocess(); err != nil {
+		t.Fatalf("Should not be fail: %s.", err)
+	}
 
 	go func() {
 		engine.Run()
@@ -444,6 +450,41 @@ func TestCtrlCWhenREngineIsRunning(t *testing.T) {
 	assert.False(t, engine.running)
 }
 
+func TestCtrlCWithFailedBin(t *testing.T) {
+	timeout := 5 * time.Second
+	done := make(chan struct{})
+	go func() {
+		dir := initWithQuickExitGoCode(t)
+		chdir(t, dir)
+		engine, err := NewEngine("", true)
+		assert.NoError(t, err)
+		engine.config.Build.Bin = "<WRONGCOMAMND>"
+		sigs := make(chan os.Signal, 1)
+		signal.Notify(sigs, syscall.SIGINT, syscall.SIGTERM)
+		var wg sync.WaitGroup
+		wg.Add(1)
+		go func() {
+			engine.Run()
+			t.Logf("engine stopped")
+			wg.Done()
+		}()
+		go func() {
+			<-sigs
+			engine.Stop()
+			t.Logf("engine stopped")
+		}()
+		time.Sleep(time.Second * 1)
+		sigs <- syscall.SIGINT
+		wg.Wait()
+		close(done)
+	}()
+	select {
+	case <-done:
+	case <-time.After(timeout):
+		t.Error("Test timed out")
+	}
+}
+
 func TestFixCloseOfChannelAfterCtrlC(t *testing.T) {
 	// fix https://github.com/cosmtrek/air/issues/294
 	dir := initWithBuildFailedCode(t)
@@ -841,7 +882,7 @@ exclude_file = ["main.go"]
 include_file = ["test/not_a_test.go"]
 
 `
-	if err := ioutil.WriteFile(dftTOML, []byte(config), 0o644); err != nil {
+	if err := os.WriteFile(dftTOML, []byte(config), 0o644); err != nil {
 		t.Fatal(err)
 	}
 	engine, err := NewEngine(".air.toml", true)
@@ -976,7 +1017,7 @@ include_ext = ["sh"]
 include_dir = ["nonexist"] # prevent default "." watch from taking effect
 include_file = ["main.sh"]
 `
-	if err := ioutil.WriteFile(dftTOML, []byte(config), 0o644); err != nil {
+	if err := os.WriteFile(dftTOML, []byte(config), 0o644); err != nil {
 		t.Fatal(err)
 	}
 
